@@ -1,9 +1,9 @@
-import typer
+import typer_cloup as typer
 
 
 def main():
     typer.echo("Opening Typer's docs")
-    typer.launch("https://alexreg-typer.netlify.app")
+    typer.launch("https://typer-cloup.netlify.app")
 
 
 if __name__ == "__main__":
