@@ -4,8 +4,8 @@ import items
 import users
 
 app = typer.Typer()
-app.add_typer(users.app, name="users")
-app.add_typer(items.app, name="items")
+app.add_sub(users.app, name="users")
+app.add_sub(items.app, name="items")
 
 if __name__ == "__main__":
     app()
