@@ -1,5 +1,5 @@
-import typer
-from typer.testing import CliRunner
+import typer_cloup as typer
+from typer_cloup.testing import CliRunner
 
 runner = CliRunner()
 
